#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-8UqOgRX75RNSAnSPIx9ka
key:                  hasql-implicits-0.1.0.5-8UqOgRX75RNSAnSPIx9ka
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  1ace2b5aa80b6a56aca1587c12eae034
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-8UqOgRX75RNSAnSPIx9ka
depends:
    aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.6.1.1-EJtRPFd4xsO77iP1mdAnE4
    network-ip-0.3.0.3-hqme7gju2HGjajc5W7f2j
    scientific-0.3.8.1-AGaiR8m7w2Z7AlSJwhzWHa text-2.0.2 time-1.12.2
    uuid-1.3.16.1-B8dHM40up0W32eC5wrEUud
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

